const bcrypt=require('bcrypt');
const jwt = require('jsonwebtoken');
const db = require('../../models');
const { json } = require('body-parser');

exports.register = async (req, res) => {
  const { email, password } = req.body;
  const role = req.body.role && req.body.role.trim() !== '' ? req.body.role : 'user';

  try {
    const existing = await db.user.findOne({ where: { email } });
    if (existing) {
      return res.json({ message: 'User already registered' });
    }
    const salt=await bcrypt.genSalt(10);
    const hashedPass=await bcrypt.hash(password,salt);
    await db.user.create({ email, password:hashedPass, role });
    return res.json({ message: 'User registered successfully' });
  } catch (err) {
    return res.json({ message: 'Registration failed', error: err.message });
  }
};

exports.login = async (req, res) => {
  const { email, password } = req.body;

  try {
    const user = await db.user.findOne({ where: { email} });

    if (!user) {
      return res.json({ message: 'Invalid credentials' });
    }
    const isMatch=await bcrypt.compare(password,user.password);
    if(!isMatch){
      return res.json({message:'Invalid credentials'});
    }
    const token = jwt.sign(
      { userId: user.id, email: user.email, role: user.role },
      process.env.JWT_SECRET,
      { expiresIn: process.env.JWT_EXPIRES_IN }
    );

    return res.json({
      message: 'Login successful',
      token,
      role: user.role
    });
  } catch (err) {
    return res.status(500).json({ message: 'Login failed', error: err.message });
  }
};
